@@ -2,20 +2,20 @@ package File::Listing::Ftpcopy;
 
 use strict;
 use warnings;
-use v5.10.1;
+use 5.008001;
 use Exporter;
 use Carp qw( croak );
 use Time::Local qw( timelocal );
 
 # ABSTRACT: parse directory listing using ftpparse from ftpcopy
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 sub parse_dir ($;$$$)
 {
   my($listing, $time_zone, $type, $error) = @_;
   
-  $error = sub { warn shift } if ($error//'') eq 'warn';
+  $error = sub { warn shift } if (defined $error ? $error : '') eq 'warn';
 
   my $next;
   if(ref($listing) eq 'ARRAY')
@@ -156,7 +156,7 @@ File::Listing::Ftpcopy - parse directory listing using ftpparse from ftpcopy
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -174,7 +174,7 @@ version 0.05
  $dir = parse_dir(\*LISTING, '+0000');
 
  # ftpparse interface
- use v5.10;
+ use 5.010;
  use Parse::Listing::Ftpcopy qw( ftpparse SIZE_UNKNOWN );
  
  foreach my $line (`ls -l`)
@@ -240,7 +240,12 @@ This module also provides a direct interface to the C<ftpparse> function as well
 
 =head1 FUNCTIONS
 
-=head2 parse_dir( $listing, [ $time_zone, [ $type, [ $error ] ] ] )
+=head2 parse_dir
+
+  my $dir = parse_dir( $listing );
+  my $dir = parse_dir( $listing, $time_zone );
+  my $dir = parse_dir( $listing, $time_zone, $type );
+  my $dir = parse_dir( $listing, $time_zone, $type, $error);
 
 The first argument ($listing) is the directory listing to parse.
 It can be a scalar, a reference to an array of directory lines or a
@@ -281,7 +286,9 @@ so this is always undef.
 Any field which could not be determined by the algorithm will be
 C<undef>.
 
-=head2 ftpparse( $line )
+=head2 ftpparse
+
+ my $hash = ftpparse( $line );
 
 Parse a single line from an FTP listing.  Returns a hash ref of
 information about the file found in that line, or undef if no
